---
name: "Bug Report \U0001F41E"
about: Something isn't working as expected? Here is the right place to report.
title: ''
labels: bug, needs triage
assignees: ''

---

Please answer these questions before submitting your issue. Thanks!

1. What version of Python are you using?

   Replace with the output of `python --version --version`

2. What operating system and processor architecture are you using?

   Replace with the output of `python -c 'import platform; print(platform.platform())'`

3. What are the component versions in the environment (`pip freeze`)?

   Replace with the output of `python -m pip freeze`

4. What did you do?

   If possible, provide a recipe for reproducing the error.
   A complete runnable program is good.

5. What did you expect to see?

   What should have happened and what happened instead?
